summaryrefslogtreecommitdiff
path: root/src/core/main.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/core/main.c')
-rw-r--r--src/core/main.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/core/main.c b/src/core/main.c
index 2bd1efd5d0..8b8e110f24 100644
--- a/src/core/main.c
+++ b/src/core/main.c
@@ -1345,10 +1345,10 @@ int main(int argc, char *argv[]) {
*/
hwclock_reset_timezone();
/* Tell the kernel our time zone */
r = hwclock_set_timezone(NULL);
if (r < 0)
- log_error("Failed to set the kernel's time zone, ignoring: %s", strerror(-r));
+ log_error("Failed to set the kernel's timezone, ignoring: %s", strerror(-r));
}
}
@@ -1345,10 +1345,10 @@ int main(int argc, char *argv[]) {
*/
hwclock_reset_timezone();
- /* Tell the kernel our time zone */
+ /* Tell the kernel our timezone */
r = hwclock_set_timezone(NULL);
if (r < 0)